# WARNING: STILL IN DEVELOPMENT

plug-email-chase
================



A Plug Python pipeline for chase emails (transactions, balance, etc)

Use
---

This library depends on python3. We recommend using a `virtualenv`
like this:

```bash
python3 -m venv ~/.virtualenvs/plug-email-chase
```

Next, install this library:

```bash
source ~/.virtualenvs/plug-email-chase/bin/activate
git clone http://github.com/lollococce/plug-email-chase
cd plug-email-chase
make install
```
Or:
```bash
source ~/.virtualenvs/plug-email-chase/bin/activate
pip install plug-email-chase
```
